@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2023 Osimis S.A., Belgium
+ * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,6 +24,8 @@
 
 #include "IValue.h"
 
+#include <Compatibility.h>
+
 namespace OrthancDatabases
 {
   class BinaryStringValue : public IValue
@@ -31,26 +34,11 @@ namespace OrthancDatabases
     std::string  content_;
 
   public:
-    explicit BinaryStringValue()
-    {
-    }
-
     explicit BinaryStringValue(const std::string& content) :
       content_(content)
     {
     }
 
-    BinaryStringValue(const void* content,
-                      size_t size)
-    {
-      content_.assign(reinterpret_cast<const char*>(content), size);
-    }
-
-    std::string& GetContent()
-    {
-      return content_;
-    }
-
     const std::string& GetContent() const
     {
       return content_;
@@ -66,13 +54,11 @@ namespace OrthancDatabases
       return content_.size();
     }
 
-    virtual ValueType GetType() const
+    virtual ValueType GetType() const ORTHANC_OVERRIDE
     {
       return ValueType_BinaryString;
     }
     
-    virtual IValue* Convert(ValueType target) const;
-
-    virtual std::string Format() const;
+    virtual IValue* Convert(ValueType target) const ORTHANC_OVERRIDE;
   };
 }
