@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2017-2023 Osimis S.A., Belgium
+ * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -185,9 +186,21 @@ namespace OrthancDatabases
       int64_t ReadInteger64(size_t field) const;
 
       std::string ReadString(size_t field) const;
+
+      void PrintResult(std::ostream& stream)
+      {
+        IResult::Print(stream, GetResult());
+      }
     };
 
 
+    /**
+     * WARNING: At any given time, there must be at most 1 object of
+     * the "CachedStatement" class in the scope, otherwise error
+     * "Cannot execute more than one statement in an implicit
+     * transaction" is generated if no explicit transaction is
+     * present.
+     **/
     class CachedStatement : public StatementBase
     {
     private:
