@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2017-2023 Osimis S.A., Belgium
+ * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -27,22 +28,50 @@
 
 namespace OrthancDatabases
 {
+  Dialect GenericFormatter::GetDialect() const
+  {
+    if (autoincrementDialect_ != namedDialect_)
+    {
+      // The two dialects do not match because of a previous call to
+      // SetAutoincrementDialect() or SetNamedDialect()
+      throw Orthanc::OrthancException(Orthanc::ErrorCode_BadSequenceOfCalls);
+    }
+    else
+    {
+      return namedDialect_;
+    }
+  }
+  
+
   void GenericFormatter::Format(std::string& target,
                                 const std::string& source,
                                 ValueType type)
   {
     if (source.empty())
     {
-      // This is the default parameter for INSERT
-      switch (dialect_)
+      throw Orthanc::OrthancException(Orthanc::ErrorCode_ParameterOutOfRange);
+    }
+    else if (source == "AUTOINCREMENT")
+    {
+      if (GetParametersCount() != 0)
+      {
+        throw Orthanc::OrthancException(Orthanc::ErrorCode_BadSequenceOfCalls,
+                                        "The AUTOINCREMENT argument must always be the first");
+      }
+      
+      switch (autoincrementDialect_)
       {
         case Dialect_PostgreSQL:
-          target = "DEFAULT";
+          target = "DEFAULT, ";
           break;
 
         case Dialect_MySQL:
         case Dialect_SQLite:
-          target = "NULL";
+          target = "NULL, ";
+          break;
+
+        case Dialect_MSSQL:
+          target.clear();  // The IDENTITY field must not be filled in MSSQL
           break;
 
         default:
@@ -51,7 +80,7 @@ namespace OrthancDatabases
     }
     else
     {
-      switch (dialect_)
+      switch (namedDialect_)
       {
         case Dialect_PostgreSQL:
           target = "$" + boost::lexical_cast<std::string>(parametersName_.size() + 1);
@@ -59,6 +88,7 @@ namespace OrthancDatabases
 
         case Dialect_MySQL:
         case Dialect_SQLite:
+        case Dialect_MSSQL:
           target = "?";
           break;
 
