@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2017-2023 Osimis S.A., Belgium
+ * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -263,13 +264,13 @@ namespace OrthancDatabases
       
     protected:
       virtual IResult* ExecuteInternal(IPrecompiledStatement& statement,
-                                       const Dictionary& parameters)
+                                       const Dictionary& parameters) ORTHANC_OVERRIDE
       {
         return dynamic_cast<PostgreSQLStatement&>(statement).Execute(*this, parameters);
       }
 
       virtual void ExecuteWithoutResultInternal(IPrecompiledStatement& statement,
-                                                const Dictionary& parameters)
+                                                const Dictionary& parameters) ORTHANC_OVERRIDE
       {
         dynamic_cast<PostgreSQLStatement&>(statement).ExecuteWithoutResult(*this, parameters);
       }
